@@ -1,21 +1,8 @@
 /*
- *   Copyright (C) 2013 Ivan Cukic <ivan.cukic(at)kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License version 2,
- *   or (at your option) any later version, as published by the Free
- *   Software Foundation
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2013 Ivan Cukic <ivan.cukic(at)kde.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef APPLICATION_H
 #define APPLICATION_H
@@ -29,12 +16,12 @@
  * Class which handles an application execution.
  *
  * Example:
- * <code>
+ * @code
  * Application {
  *     application: "xterm"
  *     running: terminalRunningCheckbox.checked
  * }
- * </code>
+ * @endcode
  */
 class Application: public QObject
 {
@@ -52,7 +39,7 @@ class Application: public QObject
     Q_PROPERTY(bool running READ running WRITE setRunning NOTIFY runningChanged)
 
 public:
-    Application(QObject *parent = Q_NULLPTR);
+    explicit Application(QObject *parent = nullptr);
     ~Application();
 
     QString application() const;
