@@ -1,26 +1,14 @@
 /*
- *   Copyright 2008-2013 Aaron Seigo <aseigo@kde.org>
- *   Copyright 2010-2013 Marco Martin <mart@kde.org>
- *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU Library General Public License as
- *   published by the Free Software Foundation; either version 2, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details
- *
- *   You should have received a copy of the GNU Library General Public
- *   License along with this program; if not, write to the
- *   Free Software Foundation, Inc.,
- *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+    SPDX-FileCopyrightText: 2008-2013 Aaron Seigo <aseigo@kde.org>
+    SPDX-FileCopyrightText: 2010-2013 Marco Martin <mart@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.0-or-later
+*/
 
 #include "appletinterface.h"
 
 #include <QAction>
+#include <QActionGroup>
 #include <QDir>
 #include <QFile>
 #include <QIcon>
@@ -33,7 +21,6 @@
 #include <KConfigLoader>
 
 #include <Plasma/Plasma>
-#include <Plasma/Applet>
 #include <Plasma/Corona>
 #include <Plasma/Package>
 #include <Plasma/PluginLoader>
@@ -111,6 +98,8 @@ AppletInterface::AppletInterface(DeclarativeAppletScript *script, const QVariant
 
     connect(applet(), &Plasma::Applet::activated,
             this, &AppletInterface::activated);
+    connect(applet(), &Plasma::Applet::containmentDisplayHintsChanged,
+            this, &AppletInterface::containmentDisplayHintsChanged);
 
     connect(appletScript(), &DeclarativeAppletScript::formFactorChanged,
             this, &AppletInterface::formFactorChanged);
@@ -245,6 +234,11 @@ Plasma::Types::Location AppletInterface::location() const
     return applet()->location();
 }
 
+Plasma::Types::ContainmentDisplayHints AppletInterface::containmentDisplayHints() const
+{
+    return applet()->containmentDisplayHints();
+}
+
 QString AppletInterface::currentActivity() const
 {
     if (applet()->containment()) {
@@ -432,6 +426,25 @@ QString AppletInterface::file(const QString &fileType, const QString &filePath)
     return appletScript()->filePath(fileType, filePath);
 }
 
+QList<QObject *> AppletInterface::contextualActionsObjects() const
+{
+    QList<QObject *> actions;
+    Plasma::Applet *a = applet();
+    if (a->failedToLaunch()) {
+        return actions;
+    }
+
+    for (const QString &name : qAsConst(m_actions)) {
+        QAction *action = a->actions()->action(name);
+
+        if (action) {
+            actions << action;
+        }
+    }
+
+    return actions;
+}
+
 QList<QAction *> AppletInterface::contextualActions() const
 {
     QList<QAction *> actions;
@@ -463,9 +476,26 @@ void AppletInterface::setActionSeparator(const QString &name)
         action->setSeparator(true);
         a->actions()->addAction(name, action);
         m_actions.append(name);
+        Q_EMIT contextualActionsChanged();
     }
 }
 
+void AppletInterface::setActionGroup(const QString &actionName, const QString &group)
+{
+    Plasma::Applet *a = applet();
+    QAction *action = a->actions()->action(actionName);
+
+    if (!action) {
+        return;
+    }
+
+    if (!m_actionGroups.contains(group)) {
+        m_actionGroups[group] = new QActionGroup(this);
+    }
+
+    action->setActionGroup(m_actionGroups[group]);
+}
+
 void AppletInterface::setAction(const QString &name, const QString &text, const QString &icon, const QString &shortcut)
 {
     Plasma::Applet *a = applet();
@@ -479,6 +509,7 @@ void AppletInterface::setAction(const QString &name, const QString &text, const
 
         Q_ASSERT(!m_actions.contains(name));
         m_actions.append(name);
+        Q_EMIT contextualActionsChanged();
 
         connect(action, &QAction::triggered, this, [this, name] {
             executeAction(name);
@@ -618,6 +649,16 @@ bool AppletInterface::hideOnWindowDeactivate() const
     return m_hideOnDeactivate;
 }
 
+void AppletInterface::setConstraintHints(Plasma::Types::ConstraintHints hints)
+{
+	m_constraintHints = hints;
+}
+
+Plasma::Types::ConstraintHints AppletInterface::constraintHints() const
+{
+	return m_constraintHints;
+}
+
 QKeySequence AppletInterface::globalShortcut() const
 {
     return applet()->globalShortcut();
@@ -884,4 +925,9 @@ bool AppletInterface::isLoading() const
     return m_loading;
 }
 
+KPluginMetaData AppletInterface::metaData() const
+{
+    return applet()->pluginMetaData();
+}
+
 #include "moc_appletinterface.cpp"
